/************************************************************************
 *
 *    Copyright (c) 1991 Microsoft Corporation.  All Rights Reserved.
 *
 *-----------------------------------------------------------------------
 *
 *     Project:  Windows Terminal Example
 *
 *      Module:  paint.c
 *
 *      Author:  Bryan A. Woodruff (baw)
 *
 *
 *     Remarks:  This module handles all painting of the terminal
 *
 *   Revisions:  
 *     01.00.000  5/ 9/91 baw   Wrote it.
 *
 ************************************************************************/

#include "terminal.h"

/************************************************************************
 *  BOOL PaintTerminal( HWND hWnd )
 *
 *  Description: 
 *     Paints the rectangle determined by the paint struct of
 *     the DC.
 *
 *  Comments:
 *      5/ 9/91  baw  Wrote it.
 *
 ************************************************************************/

BOOL PaintTerminal( HWND hWnd )
{
   int          nRow, nCol, nEndRow, nEndCol, nCount, nHorzPos, nVertPos ;
   HDC          hDC ;
   LOCALHANDLE  hTermInfo ;
   NPTERMINFO   npTermInfo ;
   PAINTSTRUCT  ps ;
   RECT         rect ;

   hTermInfo = GetWindowWord( hWnd, GWW_TERMINFO ) ;
   if (NULL == (npTermInfo = (NPTERMINFO) LocalLock( hTermInfo )))
      return ( FALSE ) ;

   hDC = BeginPaint( hWnd, &ps ) ;
   SelectObject( hDC, npTermInfo -> hFont ) ;
   rect = ps.rcPaint ;
   nRow = max( 0, (rect.top + npTermInfo -> yOffset) / npTermInfo -> yChar ) ;
   nEndRow = min( MAXROWS - 1, (rect.bottom + npTermInfo -> yOffset ) /
                               npTermInfo -> yChar ) ;
   nCol = max( 0, (rect.left + npTermInfo -> xOffset) / npTermInfo -> xChar ) ;
   nEndCol = min( MAXCOLS - 1, (rect.right + npTermInfo -> xOffset ) /
                               npTermInfo -> xChar ) ;
   nCount = nEndCol - nCol + 1 ;
   for (; nRow <= nEndRow; nRow++)
   {
      nVertPos = (nRow * npTermInfo -> yChar ) - npTermInfo -> yOffset ;
      nHorzPos = (nCol * npTermInfo -> xChar) - npTermInfo -> xOffset ;
      rect.top = nVertPos ;
      rect.bottom = nVertPos + npTermInfo -> yChar ;
      rect.left = nHorzPos ;
      rect.right = nHorzPos + npTermInfo -> xChar * nCount ;
      SetBkMode( hDC, OPAQUE ) ;
      ExtTextOut( hDC, nHorzPos, nVertPos, ETO_OPAQUE | ETO_CLIPPED, &rect,
                  (LPSTR)( npTermInfo -> abScreen + nRow * MAXCOLS + nCol ),
                  nCount, NULL ) ;
   }
   EndPaint( hWnd, &ps ) ;
   MoveTerminalCursor( hWnd ) ;
   LocalUnlock( hTermInfo ) ;
   return ( TRUE ) ;

} /* end of PaintTerminal() */

/************************************************************************
 * End of File: paint.c
 ************************************************************************/

